# Linked entities extraction with Wikipedia normalization
API client to extract entities from natural text, classify them by topic and map them to Wikipedia. Excels at texts in scientific, medical, and professional settings :)
          
                
## Installation 
* pip install --upgrade openmedicalio
* Go to [openmedical.io/ner](https://openmedical.io/gpt2) to see demo and docs!


